# Contributing

Thank you for considering a contribution to our project. 
We welcome new members to the community and this guide is meant to help you make your 
first steps with our community.

## Code of Conduct

Participants in the this project are expected to follow and uphold the [Code
of Conduct](CODE_OF_CONDUCT.md). 
Please report any unacceptable behavior to the email described therein.

## How to report bugs
We have a template for bugs in our issue tracker. 
All bugs are tracked through the issue tracker, so please use that!

## How to ask for improvements or new features

We welcome constant improvement, and we have a template for new features in our issues tracker.
You should notice that our team is small, and it may take some time for us to deal with any
specific request, or we may find that the request creates too heavy a burden for us to maintain.
If you are interested in contributing yourself, please say so in your issue. It is much easier
for us to accept new features when the community is willing to work alongside the core team on them.

## How to submit changes

All changes to the `dev` and `main` branches happen through pull requests.
Feature branches should target the `dev` branch for their pull request, where the code will be reviewed
and any appropriate checks will run.
The code will be reviewed by the community, and such a review should ensure that the committed code is
correct as well as that its quality meets our standards.
The reviewers may ask you for some changes before they are willing to merge your changes in, or they
may change some things themselves in a collaborative effort. Please remember that while your contribution
is welcome, it is always part of a group effort, and the group has the right to edit or even reject parts
of your contribution to meet the community's needs.
Such changes, suggestions and requests should always follow the Code of Conduct, as well as your own
contribution. Please report any unacceptable behavior during the review process if you encounter it.

## Code Style

We currently don't have a written-down style guide, and we should get around to it.
This may cause some friction, since style is a matter of preference, but if both you and your reviewers
apply a positive mindset that we're all trying to get the project to be at its best, we will likely
find a suitable solution.

If you find that much of your time is taken on discussions about a style guide that isn't there,
please let us know and we'll make this a higher priority.
